Class: Google::Apis::FirestoreV1beta1::BatchGetDocumentsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.BatchGetDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchGetDocumentsRequest

Returns a new instance of BatchGetDocumentsRequest.



194
195
196
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentsArray<String>

The names of the documents to retrieve. In the format: projects/project_id/ databases/database_id/documents/document_path`. The request will fail if any of the document is not a child resource of the givendatabase. Duplicate names will be elided. Corresponds to the JSON propertydocuments`

Returns:

  • (Array<String>)


161
162
163
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 161

def documents
  @documents
end

#maskGoogle::Apis::FirestoreV1beta1::DocumentMask

A set of field paths on a document. Used to restrict a get or update operation on a document to a subset of its fields. This is different from standard field masks, as this is always scoped to a Document, and takes in account the dynamic nature of Value. Corresponds to the JSON property mask



169
170
171
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 169

def mask
  @mask
end

#new_transactionGoogle::Apis::FirestoreV1beta1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



174
175
176
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 174

def new_transaction
  @new_transaction
end

#read_timeString

Reads documents as they were at the given time. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


181
182
183
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 181

def read_time
  @read_time
end

#request_optionsGoogle::Apis::FirestoreV1beta1::RequestOptions

Options for a server request. Corresponds to the JSON property requestOptions



186
187
188
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 186

def request_options
  @request_options
end

#transactionString

Reads documents in a transaction. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


192
193
194
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 192

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



199
200
201
202
203
204
205
206
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 199

def update!(**args)
  @documents = args[:documents] if args.key?(:documents)
  @mask = args[:mask] if args.key?(:mask)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @request_options = args[:request_options] if args.key?(:request_options)
  @transaction = args[:transaction] if args.key?(:transaction)
end