Class: Google::Apis::FirestoreV1beta1::BatchWriteRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.BatchWrite.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchWriteRequest

Returns a new instance of BatchWriteRequest.



273
274
275
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelsHash<String,String>

Labels associated with this batch write. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


259
260
261
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 259

def labels
  @labels
end

#request_optionsGoogle::Apis::FirestoreV1beta1::RequestOptions

Options for a server request. Corresponds to the JSON property requestOptions



264
265
266
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 264

def request_options
  @request_options
end

#writesArray<Google::Apis::FirestoreV1beta1::Write>

The writes to apply. Method does not apply writes atomically and does not guarantee ordering. Each write succeeds or fails independently. You cannot write to the same document more than once per request. Corresponds to the JSON property writes



271
272
273
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 271

def writes
  @writes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



278
279
280
281
282
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 278

def update!(**args)
  @labels = args[:labels] if args.key?(:labels)
  @request_options = args[:request_options] if args.key?(:request_options)
  @writes = args[:writes] if args.key?(:writes)
end