Class: Google::Apis::FirestoreV1beta1::CollectionSelector
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::CollectionSelector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A selection of a collection, such as messages as m1.
Instance Attribute Summary collapse
-
#all_descendants ⇒ Boolean
(also: #all_descendants?)
When false, selects only collections that are immediate children of the
parentspecified in the containingRunQueryRequest. -
#collection_id ⇒ String
The collection ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CollectionSelector
constructor
A new instance of CollectionSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CollectionSelector
Returns a new instance of CollectionSelector.
456 457 458 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_descendants ⇒ Boolean Also known as: all_descendants?
When false, selects only collections that are immediate children of the
parent specified in the containing RunQueryRequest. When true, selects all
descendant collections.
Corresponds to the JSON property allDescendants
448 449 450 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 448 def all_descendants @all_descendants end |
#collection_id ⇒ String
The collection ID. When set, selects only collections with this ID.
Corresponds to the JSON property collectionId
454 455 456 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 454 def collection_id @collection_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
461 462 463 464 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 461 def update!(**args) @all_descendants = args[:all_descendants] if args.key?(:all_descendants) @collection_id = args[:collection_id] if args.key?(:collection_id) end |