Class: Google::Apis::FirestoreV1beta1::DocumentChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A Document has changed. May be the result of multiple writes, including deletes, that ultimately resulted in a new value for the Document. Multiple DocumentChange messages may be returned for the same logical change, if multiple targets are affected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentChange

Returns a new instance of DocumentChange.



683
684
685
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 683

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentGoogle::Apis::FirestoreV1beta1::Document

A Firestore document. Must not exceed 1 MiB - 4 bytes. Corresponds to the JSON property document



671
672
673
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 671

def document
  @document
end

#removed_target_idsArray<Fixnum>

A set of target IDs for targets that no longer match this document. Corresponds to the JSON property removedTargetIds

Returns:

  • (Array<Fixnum>)


676
677
678
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 676

def removed_target_ids
  @removed_target_ids
end

#target_idsArray<Fixnum>

A set of target IDs of targets that match this document. Corresponds to the JSON property targetIds

Returns:

  • (Array<Fixnum>)


681
682
683
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 681

def target_ids
  @target_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



688
689
690
691
692
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 688

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @removed_target_ids = args[:removed_target_ids] if args.key?(:removed_target_ids)
  @target_ids = args[:target_ids] if args.key?(:target_ids)
end