Class: Google::Apis::FirestoreV1beta1::DocumentDelete

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A Document has been deleted. May be the result of multiple writes, including updates, the last of which deleted the Document. Multiple DocumentDelete messages may be returned for the same logical delete, if multiple targets are affected.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DocumentDelete

Returns a new instance of DocumentDelete.



718
719
720
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentString

The resource name of the Document that was deleted. Corresponds to the JSON property document

Returns:

  • (String)


705
706
707
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 705

def document
  @document
end

#read_timeString

The read timestamp at which the delete was observed. Greater or equal to the commit_time of the delete. Corresponds to the JSON property readTime

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 711

def read_time
  @read_time
end

#removed_target_idsArray<Fixnum>

A set of target IDs for targets that previously matched this entity. Corresponds to the JSON property removedTargetIds

Returns:

  • (Array<Fixnum>)


716
717
718
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 716

def removed_target_ids
  @removed_target_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



723
724
725
726
727
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 723

def update!(**args)
  @document = args[:document] if args.key?(:document)
  @read_time = args[:read_time] if args.key?(:read_time)
  @removed_target_ids = args[:removed_target_ids] if args.key?(:removed_target_ids)
end