Class: Google::Apis::FirestoreV1beta1::ExecutionStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Execution statistics for the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionStats

Returns a new instance of ExecutionStats.



995
996
997
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#debug_statsHash<String,Object>

Debugging statistics from the execution of the query. Note that the debugging stats are subject to change as Firestore evolves. It could include: " indexes_entries_scanned": "1000", "documents_scanned": "20", "billing_details" : "documents_billable": "20", "index_entries_billable": "1000", " min_query_cost": "0" Corresponds to the JSON property debugStats

Returns:

  • (Hash<String,Object>)


977
978
979
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 977

def debug_stats
  @debug_stats
end

#execution_durationString

Total time to execute the query in the backend. Corresponds to the JSON property executionDuration

Returns:

  • (String)


982
983
984
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 982

def execution_duration
  @execution_duration
end

#read_operationsFixnum

Total billable read operations. Corresponds to the JSON property readOperations

Returns:

  • (Fixnum)


987
988
989
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 987

def read_operations
  @read_operations
end

#results_returnedFixnum

Total number of results returned, including documents, projections, aggregation results, keys. Corresponds to the JSON property resultsReturned

Returns:

  • (Fixnum)


993
994
995
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 993

def results_returned
  @results_returned
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1000
1001
1002
1003
1004
1005
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1000

def update!(**args)
  @debug_stats = args[:debug_stats] if args.key?(:debug_stats)
  @execution_duration = args[:execution_duration] if args.key?(:execution_duration)
  @read_operations = args[:read_operations] if args.key?(:read_operations)
  @results_returned = args[:results_returned] if args.key?(:results_returned)
end