Class: Google::Apis::FirestoreV1beta1::ExplainOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Explain options for the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainOptions

Returns a new instance of ExplainOptions.



1089
1090
1091
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analyzeBoolean Also known as: analyze?

Optional. Whether to execute this query. When false (the default), the query will be planned, returning only metrics from the planning stages. When true, the query will be planned and executed, returning the full query results along with both planning and execution stage metrics. Corresponds to the JSON property analyze

Returns:

  • (Boolean)


1086
1087
1088
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1086

def analyze
  @analyze
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1094
1095
1096
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1094

def update!(**args)
  @analyze = args[:analyze] if args.key?(:analyze)
end