Class: Google::Apis::FirestoreV1beta1::ExplainStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Pipeline explain stats. Depending on the explain options in the original request, this can contain the optimized plan and / or execution stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainStats

Returns a new instance of ExplainStats.



1072
1073
1074
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1072

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataHash<String,Object>

The format depends on the output_format options in the request. Currently there are two supported options: TEXT and JSON. Both supply a google. protobuf.StringValue. Corresponds to the JSON property data

Returns:

  • (Hash<String,Object>)


1070
1071
1072
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1070

def data
  @data
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1077
1078
1079
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1077

def update!(**args)
  @data = args[:data] if args.key?(:data)
end