Class: Google::Apis::FirestoreV1beta1::FieldTransform
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::FieldTransform
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A transformation of a field of the document.
Instance Attribute Summary collapse
-
#append_missing_elements ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
-
#field_path ⇒ String
The path of the field.
-
#increment ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
-
#maximum ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
-
#minimum ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
-
#remove_all_from_array ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
-
#set_to_server_value ⇒ String
Sets the field to the given server value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FieldTransform
constructor
A new instance of FieldTransform.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FieldTransform
Returns a new instance of FieldTransform.
1173 1174 1175 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append_missing_elements ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
Corresponds to the JSON property appendMissingElements
1141 1142 1143 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1141 def append_missing_elements @append_missing_elements end |
#field_path ⇒ String
The path of the field. See Document.fields for the field path syntax reference.
Corresponds to the JSON property fieldPath
1146 1147 1148 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1146 def field_path @field_path end |
#increment ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
Corresponds to the JSON property increment
1151 1152 1153 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1151 def increment @increment end |
#maximum ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
Corresponds to the JSON property maximum
1156 1157 1158 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1156 def maximum @maximum end |
#minimum ⇒ Google::Apis::FirestoreV1beta1::Value
A message that can hold any of the supported value types.
Corresponds to the JSON property minimum
1161 1162 1163 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1161 def minimum @minimum end |
#remove_all_from_array ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
Corresponds to the JSON property removeAllFromArray
1166 1167 1168 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1166 def remove_all_from_array @remove_all_from_array end |
#set_to_server_value ⇒ String
Sets the field to the given server value.
Corresponds to the JSON property setToServerValue
1171 1172 1173 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1171 def set_to_server_value @set_to_server_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1178 def update!(**args) @append_missing_elements = args[:append_missing_elements] if args.key?(:append_missing_elements) @field_path = args[:field_path] if args.key?(:field_path) @increment = args[:increment] if args.key?(:increment) @maximum = args[:maximum] if args.key?(:maximum) @minimum = args[:minimum] if args.key?(:minimum) @remove_all_from_array = args[:remove_all_from_array] if args.key?(:remove_all_from_array) @set_to_server_value = args[:set_to_server_value] if args.key?(:set_to_server_value) end |