Class: Google::Apis::FirestoreV1beta1::FirestoreService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FirestoreV1beta1::FirestoreService
- Defined in:
- lib/google/apis/firestore_v1beta1/service.rb
Overview
Cloud Firestore API
Accesses the NoSQL document database built for automatic scaling, high performance, and ease of application development.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://firestore.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_document_write(database, batch_write_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BatchWriteResponse
Applies a batch of write operations.
-
#batch_get_documents(database, batch_get_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse
Gets multiple documents.
-
#begin_document_transaction(database, begin_transaction_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BeginTransactionResponse
Starts a new transaction.
-
#commit_document(database, commit_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::CommitResponse
Commits a transaction, while optionally updating documents.
-
#create_project_database_document_document(parent, collection_id, document_object = nil, document_id: nil, mask_field_paths: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Creates a new document.
-
#create_project_database_index(parent, google_firestore_admin_v1beta1_index_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Creates the specified index.
-
#delete_project_database_document(name, current_document_exists: nil, current_document_update_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Deletes a document.
-
#delete_project_database_index(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Deletes an index.
-
#execute_document_pipeline(database, execute_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ExecutePipelineResponse
Executes a pipeline query.
-
#export_project_database_documents(name, google_firestore_admin_v1beta1_export_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Exports a copy of all or a subset of documents from Google Cloud Firestore to another storage system, such as Google Cloud Storage.
-
#get_project_database_document(name, mask_field_paths: nil, read_time: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Gets a single document.
-
#get_project_database_index(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Index
Gets an index.
-
#import_project_database_documents(name, google_firestore_admin_v1beta1_import_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Imports documents into Google Cloud Firestore.
-
#initialize ⇒ FirestoreService
constructor
A new instance of FirestoreService.
-
#list_project_database_document_collection_ids(parent, list_collection_ids_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListCollectionIdsResponse
Lists all the collection IDs underneath a document.
-
#list_project_database_document_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListDocumentsResponse
Lists documents.
-
#list_project_database_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListDocumentsResponse
Lists documents.
-
#list_project_database_indexes(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ListIndexesResponse
Lists the indexes that match the specified filters.
-
#listen_document(database, listen_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListenResponse
Listens to changes.
-
#partition_document_query(parent, partition_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::PartitionQueryResponse
Partitions a query by returning partition cursors that can be used to run the query in parallel.
-
#patch_project_database_document(name, document_object = nil, current_document_exists: nil, current_document_update_time: nil, mask_field_paths: nil, update_mask_field_paths: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Updates or inserts a document.
-
#rollback_document(database, rollback_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Rolls back a transaction.
-
#run_document_aggregation_query(parent, run_aggregation_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::RunAggregationQueryResponse
Runs an aggregation query.
-
#run_document_query(parent, run_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::RunQueryResponse
Runs a query.
-
#write_document(database, write_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::WriteResponse
Streams batches of document updates and deletes, in order.
Constructor Details
#initialize ⇒ FirestoreService
Returns a new instance of FirestoreService.
48 49 50 51 52 53 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-firestore_v1beta1', client_version: Google::Apis::FirestoreV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#batch_document_write(database, batch_write_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BatchWriteResponse
Applies a batch of write operations. The BatchWrite method does not apply the write operations atomically and can apply them out of order. Method does not allow more than one write per document. Each write succeeds or fails independently. See the BatchWriteResponse for the success status of each write. If you require an atomically applied set of writes, use Commit instead.
194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 194 def batch_document_write(database, batch_write_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:batchWrite', ) command.request_representation = Google::Apis::FirestoreV1beta1::BatchWriteRequest::Representation command.request_object = batch_write_request_object command.response_representation = Google::Apis::FirestoreV1beta1::BatchWriteResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::BatchWriteResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#batch_get_documents(database, batch_get_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse
Gets multiple documents. Documents returned by this method are not guaranteed to be returned in the same order that they were requested.
156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 156 def batch_get_documents(database, batch_get_documents_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:batchGet', ) command.request_representation = Google::Apis::FirestoreV1beta1::BatchGetDocumentsRequest::Representation command.request_object = batch_get_documents_request_object command.response_representation = Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#begin_document_transaction(database, begin_transaction_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::BeginTransactionResponse
Starts a new transaction.
228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 228 def begin_document_transaction(database, begin_transaction_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:beginTransaction', ) command.request_representation = Google::Apis::FirestoreV1beta1::BeginTransactionRequest::Representation command.request_object = begin_transaction_request_object command.response_representation = Google::Apis::FirestoreV1beta1::BeginTransactionResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::BeginTransactionResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#commit_document(database, commit_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::CommitResponse
Commits a transaction, while optionally updating documents.
262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 262 def commit_document(database, commit_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:commit', ) command.request_representation = Google::Apis::FirestoreV1beta1::CommitRequest::Representation command.request_object = commit_request_object command.response_representation = Google::Apis::FirestoreV1beta1::CommitResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::CommitResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_database_document_document(parent, collection_id, document_object = nil, document_id: nil, mask_field_paths: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Creates a new document.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 306 def create_project_database_document_document(parent, collection_id, document_object = nil, document_id: nil, mask_field_paths: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/{collectionId}', ) command.request_representation = Google::Apis::FirestoreV1beta1::Document::Representation command.request_object = document_object command.response_representation = Google::Apis::FirestoreV1beta1::Document::Representation command.response_class = Google::Apis::FirestoreV1beta1::Document command.params['parent'] = parent unless parent.nil? command.params['collectionId'] = collection_id unless collection_id.nil? command.query['documentId'] = document_id unless document_id.nil? command.query['mask.fieldPaths'] = mask_field_paths unless mask_field_paths.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_database_index(parent, google_firestore_admin_v1beta1_index_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Creates the specified index. A newly created index's initial state is
CREATING. On completion of the returned google.longrunning.Operation, the
state will be READY. If the index already exists, the call will return an
ALREADY_EXISTS status. During creation, the process could result in an error,
in which case the index will move to the ERROR state. The process can be
recovered by fixing the data that caused the error, removing the index with
delete, then re-creating the index with create. Indexes with a single field
cannot be created.
919 920 921 922 923 924 925 926 927 928 929 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 919 def create_project_database_index(parent, google_firestore_admin_v1beta1_index_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/indexes', ) command.request_representation = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Index::Representation command.request_object = google_firestore_admin_v1beta1_index_object command.response_representation = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_database_document(name, current_document_exists: nil, current_document_update_time: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Deletes a document.
348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 348 def delete_project_database_document(name, current_document_exists: nil, current_document_update_time: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirestoreV1beta1::Empty::Representation command.response_class = Google::Apis::FirestoreV1beta1::Empty command.params['name'] = name unless name.nil? command.query['currentDocument.exists'] = current_document_exists unless current_document_exists.nil? command.query['currentDocument.updateTime'] = current_document_update_time unless current_document_update_time.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_database_index(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Deletes an index.
952 953 954 955 956 957 958 959 960 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 952 def delete_project_database_index(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirestoreV1beta1::Empty::Representation command.response_class = Google::Apis::FirestoreV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_document_pipeline(database, execute_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ExecutePipelineResponse
Executes a pipeline query.
382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 382 def execute_document_pipeline(database, execute_pipeline_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:executePipeline', ) command.request_representation = Google::Apis::FirestoreV1beta1::ExecutePipelineRequest::Representation command.request_object = execute_pipeline_request_object command.response_representation = Google::Apis::FirestoreV1beta1::ExecutePipelineResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::ExecutePipelineResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#export_project_database_documents(name, google_firestore_admin_v1beta1_export_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Exports a copy of all or a subset of documents from Google Cloud Firestore to another storage system, such as Google Cloud Storage. Recent updates to documents may not be reflected in the export. The export occurs in the background and its progress can be monitored and managed via the Operation resource that is created. The output of an export may only be used once the associated operation is done. If an export operation is cancelled before completion it may leave partial data behind in Google Cloud Storage.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 83 def export_project_database_documents(name, google_firestore_admin_v1beta1_export_documents_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:exportDocuments', ) command.request_representation = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ExportDocumentsRequest::Representation command.request_object = google_firestore_admin_v1beta1_export_documents_request_object command.response_representation = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_database_document(name, mask_field_paths: nil, read_time: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Gets a single document.
425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 425 def get_project_database_document(name, mask_field_paths: nil, read_time: nil, transaction: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirestoreV1beta1::Document::Representation command.response_class = Google::Apis::FirestoreV1beta1::Document command.params['name'] = name unless name.nil? command.query['mask.fieldPaths'] = mask_field_paths unless mask_field_paths.nil? command.query['readTime'] = read_time unless read_time.nil? command.query['transaction'] = transaction unless transaction.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_database_index(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Index
Gets an index.
983 984 985 986 987 988 989 990 991 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 983 def get_project_database_index(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Index::Representation command.response_class = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Index command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#import_project_database_documents(name, google_firestore_admin_v1beta1_import_documents_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation
Imports documents into Google Cloud Firestore. Existing documents with the same name are overwritten. The import occurs in the background and its progress can be monitored and managed via the Operation resource that is created. If an ImportDocuments operation is cancelled, it is possible that a subset of the data has already been imported to Cloud Firestore.
121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 121 def import_project_database_documents(name, google_firestore_admin_v1beta1_import_documents_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:importDocuments', ) command.request_representation = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ImportDocumentsRequest::Representation command.request_object = google_firestore_admin_v1beta1_import_documents_request_object command.response_representation = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::FirestoreV1beta1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_database_document_collection_ids(parent, list_collection_ids_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListCollectionIdsResponse
Lists all the collection IDs underneath a document.
535 536 537 538 539 540 541 542 543 544 545 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 535 def list_project_database_document_collection_ids(parent, list_collection_ids_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:listCollectionIds', ) command.request_representation = Google::Apis::FirestoreV1beta1::ListCollectionIdsRequest::Representation command.request_object = list_collection_ids_request_object command.response_representation = Google::Apis::FirestoreV1beta1::ListCollectionIdsResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::ListCollectionIdsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_database_document_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListDocumentsResponse
Lists documents.
603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 603 def list_project_database_document_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/{collectionId}', ) command.response_representation = Google::Apis::FirestoreV1beta1::ListDocumentsResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::ListDocumentsResponse command.params['parent'] = parent unless parent.nil? command.params['collectionId'] = collection_id unless collection_id.nil? command.query['mask.fieldPaths'] = mask_field_paths unless mask_field_paths.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['readTime'] = read_time unless read_time.nil? command.query['showMissing'] = show_missing unless show_missing.nil? command.query['transaction'] = transaction unless transaction.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_database_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListDocumentsResponse
Lists documents.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 494 def list_project_database_documents(parent, collection_id, mask_field_paths: nil, order_by: nil, page_size: nil, page_token: nil, read_time: nil, show_missing: nil, transaction: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/{collectionId}', ) command.response_representation = Google::Apis::FirestoreV1beta1::ListDocumentsResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::ListDocumentsResponse command.params['parent'] = parent unless parent.nil? command.params['collectionId'] = collection_id unless collection_id.nil? command.query['mask.fieldPaths'] = mask_field_paths unless mask_field_paths.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['readTime'] = read_time unless read_time.nil? command.query['showMissing'] = show_missing unless show_missing.nil? command.query['transaction'] = transaction unless transaction.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_database_indexes(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ListIndexesResponse
Lists the indexes that match the specified filters.
1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 1018 def list_project_database_indexes(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/indexes', ) command.response_representation = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ListIndexesResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ListIndexesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#listen_document(database, listen_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::ListenResponse
Listens to changes. This method is only available via gRPC or WebChannel (not REST).
644 645 646 647 648 649 650 651 652 653 654 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 644 def listen_document(database, listen_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:listen', ) command.request_representation = Google::Apis::FirestoreV1beta1::ListenRequest::Representation command.request_object = listen_request_object command.response_representation = Google::Apis::FirestoreV1beta1::ListenResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::ListenResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#partition_document_query(parent, partition_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::PartitionQueryResponse
Partitions a query by returning partition cursors that can be used to run the query in parallel. The returned partition cursors are split points that can be used by RunQuery as starting/end points for the query results.
681 682 683 684 685 686 687 688 689 690 691 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 681 def partition_document_query(parent, partition_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:partitionQuery', ) command.request_representation = Google::Apis::FirestoreV1beta1::PartitionQueryRequest::Representation command.request_object = partition_query_request_object command.response_representation = Google::Apis::FirestoreV1beta1::PartitionQueryResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::PartitionQueryResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_database_document(name, document_object = nil, current_document_exists: nil, current_document_update_time: nil, mask_field_paths: nil, update_mask_field_paths: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Document
Updates or inserts a document.
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 727 def patch_project_database_document(name, document_object = nil, current_document_exists: nil, current_document_update_time: nil, mask_field_paths: nil, update_mask_field_paths: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FirestoreV1beta1::Document::Representation command.request_object = document_object command.response_representation = Google::Apis::FirestoreV1beta1::Document::Representation command.response_class = Google::Apis::FirestoreV1beta1::Document command.params['name'] = name unless name.nil? command.query['currentDocument.exists'] = current_document_exists unless current_document_exists.nil? command.query['currentDocument.updateTime'] = current_document_update_time unless current_document_update_time.nil? command.query['mask.fieldPaths'] = mask_field_paths unless mask_field_paths.nil? command.query['updateMask.fieldPaths'] = update_mask_field_paths unless update_mask_field_paths.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rollback_document(database, rollback_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::Empty
Rolls back a transaction.
765 766 767 768 769 770 771 772 773 774 775 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 765 def rollback_document(database, rollback_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:rollback', ) command.request_representation = Google::Apis::FirestoreV1beta1::RollbackRequest::Representation command.request_object = rollback_request_object command.response_representation = Google::Apis::FirestoreV1beta1::Empty::Representation command.response_class = Google::Apis::FirestoreV1beta1::Empty command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_document_aggregation_query(parent, run_aggregation_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::RunAggregationQueryResponse
Runs an aggregation query. Rather than producing Document results like
Firestore.RunQuery, this API allows running an aggregation to produce a series
of AggregationResult server-side. High-Level Example: -- Return the number
of documents in table given a filter. SELECT COUNT(*) FROM ( SELECT * FROM k
where a = true );
806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 806 def run_document_aggregation_query(parent, run_aggregation_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:runAggregationQuery', ) command.request_representation = Google::Apis::FirestoreV1beta1::RunAggregationQueryRequest::Representation command.request_object = run_aggregation_query_request_object command.response_representation = Google::Apis::FirestoreV1beta1::RunAggregationQueryResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::RunAggregationQueryResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#run_document_query(parent, run_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::RunQueryResponse
Runs a query.
843 844 845 846 847 848 849 850 851 852 853 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 843 def run_document_query(parent, run_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}:runQuery', ) command.request_representation = Google::Apis::FirestoreV1beta1::RunQueryRequest::Representation command.request_object = run_query_request_object command.response_representation = Google::Apis::FirestoreV1beta1::RunQueryResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::RunQueryResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#write_document(database, write_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FirestoreV1beta1::WriteResponse
Streams batches of document updates and deletes, in order. This method is only available via gRPC or WebChannel (not REST).
878 879 880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/firestore_v1beta1/service.rb', line 878 def write_document(database, write_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+database}/documents:write', ) command.request_representation = Google::Apis::FirestoreV1beta1::WriteRequest::Representation command.request_object = write_request_object command.response_representation = Google::Apis::FirestoreV1beta1::WriteResponse::Representation command.response_class = Google::Apis::FirestoreV1beta1::WriteResponse command.params['database'] = database unless database.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |