Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. BulkDeleteDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.



1372
1373
1374
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

The IDs of the collection groups that are being deleted. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


1330
1331
1332
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1330

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1336

def end_time
  @end_time
end

#namespace_idsArray<String>

Which namespace IDs are being deleted. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


1341
1342
1343
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1341

def namespace_ids
  @namespace_ids
end

#operation_stateString

The state of the operation. Corresponds to the JSON property operationState

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1346

def operation_state
  @operation_state
end

#progress_bytesGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



1352
1353
1354
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1352

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



1358
1359
1360
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1358

def progress_documents
  @progress_documents
end

#snapshot_timeString

The timestamp that corresponds to the version of the database that is being read to get the list of documents to delete. This time can also be used as the timestamp of PITR in case of disaster recovery (subject to PITR window limit). Corresponds to the JSON property snapshotTime

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1365

def snapshot_time
  @snapshot_time
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


1370
1371
1372
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1370

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1377

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end