Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1CloneDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for the long-running operation from the CloneDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.



1458
1459
1460
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

The name of the database being cloned to. Corresponds to the JSON property database

Returns:

  • (String)


1426
1427
1428
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1426

def database
  @database
end

#end_timeString

The time the clone finished, unset for ongoing clones. Corresponds to the JSON property endTime

Returns:

  • (String)


1431
1432
1433
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1431

def end_time
  @end_time
end

#operation_stateString

The operation state of the clone. Corresponds to the JSON property operationState

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1436

def operation_state
  @operation_state
end

#pitr_snapshotGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot

A consistent snapshot of a database at a specific point in time. A PITR (Point- in-time recovery) snapshot with previous versions of a database's data is available for every minute up to the associated database's data retention period. If the PITR feature is enabled, the retention period is 7 days; otherwise, it is one hour. Corresponds to the JSON property pitrSnapshot



1445
1446
1447
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1445

def pitr_snapshot
  @pitr_snapshot
end

#progress_percentageGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



1451
1452
1453
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1451

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the clone was started. Corresponds to the JSON property startTime

Returns:

  • (String)


1456
1457
1458
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1456

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1463

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @pitr_snapshot = args[:pitr_snapshot] if args.key?(:pitr_snapshot)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end