Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A consistent snapshot of a database at a specific point in time. A PITR (Point- in-time recovery) snapshot with previous versions of a database's data is available for every minute up to the associated database's data retention period. If the PITR feature is enabled, the retention period is 7 days; otherwise, it is one hour.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1PitrSnapshot

Returns a new instance of GoogleFirestoreAdminV1PitrSnapshot.



1524
1525
1526
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

Required. The name of the database that this was a snapshot of. Format: projects/project/databases/database`. Corresponds to the JSON propertydatabase`

Returns:

  • (String)


1511
1512
1513
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1511

def database
  @database
end

#database_uidString

Output only. Public UUID of the database the snapshot was associated with. Corresponds to the JSON property databaseUid NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


1517
1518
1519
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1517

def database_uid
  @database_uid
end

#snapshot_timeString

Required. Snapshot time of the database. Corresponds to the JSON property snapshotTime

Returns:

  • (String)


1522
1523
1524
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1522

def snapshot_time
  @snapshot_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1529
1530
1531
1532
1533
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1529

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @database_uid = args[:database_uid] if args.key?(:database_uid)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
end