Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



1567
1568
1569
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


1539
1540
1541
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1539

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


1544
1545
1546
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1544

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


1549
1550
1551
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1549

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


1554
1555
1556
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1554

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



1560
1561
1562
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1560

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


1565
1566
1567
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1565

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1572
1573
1574
1575
1576
1577
1578
1579
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1572

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end