Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ImportDocumentsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1ImportDocumentsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
Metadata for ImportDocuments operations.
Instance Attribute Summary collapse
-
#collection_ids ⇒ Array<String>
Which collection ids are being imported.
-
#end_time ⇒ String
The time the operation ended, either successfully or otherwise.
-
#input_uri_prefix ⇒ String
The location of the documents being imported.
-
#operation_state ⇒ String
The state of the import operation.
-
#progress_bytes ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
Measures the progress of a particular metric.
-
#progress_documents ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
Measures the progress of a particular metric.
-
#start_time ⇒ String
The time that work began on the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1ImportDocumentsMetadata
constructor
A new instance of GoogleFirestoreAdminV1beta1ImportDocumentsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1ImportDocumentsMetadata
Returns a new instance of GoogleFirestoreAdminV1beta1ImportDocumentsMetadata.
1792 1793 1794 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection_ids ⇒ Array<String>
Which collection ids are being imported.
Corresponds to the JSON property collectionIds
1759 1760 1761 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1759 def collection_ids @collection_ids end |
#end_time ⇒ String
The time the operation ended, either successfully or otherwise. Unset if the
operation is still active.
Corresponds to the JSON property endTime
1765 1766 1767 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1765 def end_time @end_time end |
#input_uri_prefix ⇒ String
The location of the documents being imported.
Corresponds to the JSON property inputUriPrefix
1770 1771 1772 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1770 def input_uri_prefix @input_uri_prefix end |
#operation_state ⇒ String
The state of the import operation.
Corresponds to the JSON property operationState
1775 1776 1777 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1775 def operation_state @operation_state end |
#progress_bytes ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
Measures the progress of a particular metric.
Corresponds to the JSON property progressBytes
1780 1781 1782 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1780 def progress_bytes @progress_bytes end |
#progress_documents ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
Measures the progress of a particular metric.
Corresponds to the JSON property progressDocuments
1785 1786 1787 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1785 def progress_documents @progress_documents end |
#start_time ⇒ String
The time that work began on the operation.
Corresponds to the JSON property startTime
1790 1791 1792 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1790 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1797 1798 1799 1800 1801 1802 1803 1804 1805 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1797 def update!(**args) @collection_ids = args[:collection_ids] if args.key?(:collection_ids) @end_time = args[:end_time] if args.key?(:end_time) @input_uri_prefix = args[:input_uri_prefix] if args.key?(:input_uri_prefix) @operation_state = args[:operation_state] if args.key?(:operation_state) @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes) @progress_documents = args[:progress_documents] if args.key?(:progress_documents) @start_time = args[:start_time] if args.key?(:start_time) end |