Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Measures the progress of a particular metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1Progress

Returns a new instance of GoogleFirestoreAdminV1beta1Progress.



2010
2011
2012
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2010

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#work_completedFixnum

An estimate of how much work has been completed. Note that this may be greater than work_estimated. Corresponds to the JSON property workCompleted

Returns:

  • (Fixnum)


2002
2003
2004
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2002

def work_completed
  @work_completed
end

#work_estimatedFixnum

An estimate of how much work needs to be performed. Zero if the work estimate is unavailable. May change as work progresses. Corresponds to the JSON property workEstimated

Returns:

  • (Fixnum)


2008
2009
2010
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2008

def work_estimated
  @work_estimated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2015
2016
2017
2018
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2015

def update!(**args)
  @work_completed = args[:work_completed] if args.key?(:work_completed)
  @work_estimated = args[:work_estimated] if args.key?(:work_estimated)
end