Class: Google::Apis::FirestoreV1beta1::ListCollectionIdsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.ListCollectionIds.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCollectionIdsRequest

Returns a new instance of ListCollectionIdsRequest.



2137
2138
2139
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

The maximum number of results to return. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


2118
2119
2120
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2118

def page_size
  @page_size
end

#page_tokenString

A page token. Must be a value from ListCollectionIdsResponse. Corresponds to the JSON property pageToken

Returns:

  • (String)


2123
2124
2125
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2123

def page_token
  @page_token
end

#read_timeString

Reads documents as they were at the given time. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


2130
2131
2132
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2130

def read_time
  @read_time
end

#request_optionsGoogle::Apis::FirestoreV1beta1::RequestOptions

Options for a server request. Corresponds to the JSON property requestOptions



2135
2136
2137
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2135

def request_options
  @request_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2142
2143
2144
2145
2146
2147
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2142

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @read_time = args[:read_time] if args.key?(:read_time)
  @request_options = args[:request_options] if args.key?(:request_options)
end