Class: Google::Apis::FirestoreV1beta1::ListDocumentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::ListDocumentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
The response for Firestore.ListDocuments.
Instance Attribute Summary collapse
-
#documents ⇒ Array<Google::Apis::FirestoreV1beta1::Document>
The Documents found.
-
#next_page_token ⇒ String
A token to retrieve the next page of documents.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDocumentsResponse
constructor
A new instance of ListDocumentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDocumentsResponse
Returns a new instance of ListDocumentsResponse.
2126 2127 2128 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#documents ⇒ Array<Google::Apis::FirestoreV1beta1::Document>
The Documents found.
Corresponds to the JSON property documents
2118 2119 2120 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2118 def documents @documents end |
#next_page_token ⇒ String
A token to retrieve the next page of documents. If this field is omitted,
there are no subsequent pages.
Corresponds to the JSON property nextPageToken
2124 2125 2126 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2124 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2131 2132 2133 2134 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2131 def update!(**args) @documents = args[:documents] if args.key?(:documents) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |