Class: Google::Apis::FirestoreV1beta1::PartitionQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The response for Firestore.PartitionQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitionQueryResponse

Returns a new instance of PartitionQueryResponse.



2433
2434
2435
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A page token that may be used to request an additional set of results, up to the number specified by partition_count in the PartitionQuery request. If blank, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2417
2418
2419
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2417

def next_page_token
  @next_page_token
end

#partitionsArray<Google::Apis::FirestoreV1beta1::Cursor>

Partition results. Each partition is a split point that can be used by RunQuery as a starting or end point for the query results. The RunQuery requests must be made with the same query supplied to this PartitionQuery request. The partition cursors will be ordered according to same ordering as the results of the query supplied to PartitionQuery. For example, if a PartitionQuery request returns partition cursors A and B, running the following three queries will return the entire result set of the original query: * query, end_at A * query, start_at A, end_at B * query, start_at B An empty result may indicate that the query has too few results to be partitioned, or that the query is not yet supported for partitioning. Corresponds to the JSON property partitions



2431
2432
2433
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2431

def partitions
  @partitions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2438
2439
2440
2441
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2438

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @partitions = args[:partitions] if args.key?(:partitions)
end