Class: Google::Apis::FirestoreV1beta1::RunAggregationQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.RunAggregationQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunAggregationQueryRequest

Returns a new instance of RunAggregationQueryRequest.



2678
2679
2680
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_optionsGoogle::Apis::FirestoreV1beta1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



2647
2648
2649
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2647

def explain_options
  @explain_options
end

#new_transactionGoogle::Apis::FirestoreV1beta1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



2652
2653
2654
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2652

def new_transaction
  @new_transaction
end

#read_timeString

Executes the query at the given timestamp. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


2659
2660
2661
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2659

def read_time
  @read_time
end

#request_optionsGoogle::Apis::FirestoreV1beta1::RequestOptions

Options for a server request. Corresponds to the JSON property requestOptions



2664
2665
2666
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2664

def request_options
  @request_options
end

#structured_aggregation_queryGoogle::Apis::FirestoreV1beta1::StructuredAggregationQuery

Firestore query for running an aggregation over a StructuredQuery. Corresponds to the JSON property structuredAggregationQuery



2669
2670
2671
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2669

def structured_aggregation_query
  @structured_aggregation_query
end

#transactionString

Run the aggregation within an already active transaction. The value here is the opaque transaction ID to execute the query in. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2676
2677
2678
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2676

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2683
2684
2685
2686
2687
2688
2689
2690
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2683

def update!(**args)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @request_options = args[:request_options] if args.key?(:request_options)
  @structured_aggregation_query = args[:structured_aggregation_query] if args.key?(:structured_aggregation_query)
  @transaction = args[:transaction] if args.key?(:transaction)
end