Class: Google::Apis::FirestoreV1beta1::Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A message that can hold any of the supported value types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Value

Returns a new instance of Value.



3409
3410
3411
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valueGoogle::Apis::FirestoreV1beta1::ArrayValue

An array value. Corresponds to the JSON property arrayValue



3316
3317
3318
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3316

def array_value
  @array_value
end

#boolean_valueBoolean Also known as: boolean_value?

A boolean value. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


3321
3322
3323
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3321

def boolean_value
  @boolean_value
end

#bytes_valueString

A bytes value. In Standard edition databases: * The value must not exceed 1 MiB - 89 bytes. * Only the first 1,500 bytes are considered by queries. In Enterprise edition databases, there is no limit on the size of the value. However, it is still subject to document and index entry size limits. Corresponds to the JSON property bytesValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3331
3332
3333
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3331

def bytes_value
  @bytes_value
end

#double_valueFloat

A double value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


3336
3337
3338
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3336

def double_value
  @double_value
end

#field_reference_valueString

Value which references a field. This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document. * Requires:* * Must follow field reference limitations. * Not allowed to be used when writing documents. Corresponds to the JSON property fieldReferenceValue

Returns:

  • (String)


3344
3345
3346
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3344

def field_reference_value
  @field_reference_value
end

#function_valueGoogle::Apis::FirestoreV1beta1::Function

Represents an unevaluated scalar expression. For example, the expression like( user_name, "%alice%") is represented as: name: "like" args ` field_reference: "user_name" ` args ` string_value: "%alice%" ` Corresponds to the JSON property functionValue



3351
3352
3353
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3351

def function_value
  @function_value
end

#geo_point_valueGoogle::Apis::FirestoreV1beta1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property geoPointValue



3359
3360
3361
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3359

def geo_point_value
  @geo_point_value
end

#integer_valueFixnum

An integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


3364
3365
3366
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3364

def integer_value
  @integer_value
end

#map_valueGoogle::Apis::FirestoreV1beta1::MapValue

A map value. Corresponds to the JSON property mapValue



3369
3370
3371
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3369

def map_value
  @map_value
end

#null_valueString

A null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


3374
3375
3376
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3374

def null_value
  @null_value
end

#pipeline_valueGoogle::Apis::FirestoreV1beta1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipelineValue



3379
3380
3381
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3379

def pipeline_value
  @pipeline_value
end

#reference_valueString

A reference to a document. For example: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertyreferenceValue`

Returns:

  • (String)


3385
3386
3387
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3385

def reference_value
  @reference_value
end

#string_valueString

A string value. In Standard edition databases: * The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. * Only the first 1,500 bytes of the UTF-8 representation are considered by queries. In Enterprise edition databases, there is no limit on the size of the value. However, it is still subject to document and index entry size limits. Corresponds to the JSON property stringValue

Returns:

  • (String)


3394
3395
3396
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3394

def string_value
  @string_value
end

#timestamp_valueString

A timestamp value. Precise only to microseconds. When stored, any additional precision is rounded down. Corresponds to the JSON property timestampValue

Returns:

  • (String)


3400
3401
3402
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3400

def timestamp_value
  @timestamp_value
end

#variable_reference_valueString

Pointer to a variable defined elsewhere in a pipeline. Unlike field_reference_value which references a field within a document, this refers to a variable, defined in a separate namespace than the fields of a document. Corresponds to the JSON property variableReferenceValue

Returns:

  • (String)


3407
3408
3409
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3407

def variable_reference_value
  @variable_reference_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3414
3415
3416
3417
3418
3419
3420
3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3414

def update!(**args)
  @array_value = args[:array_value] if args.key?(:array_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @bytes_value = args[:bytes_value] if args.key?(:bytes_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value)
  @function_value = args[:function_value] if args.key?(:function_value)
  @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @map_value = args[:map_value] if args.key?(:map_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value)
  @reference_value = args[:reference_value] if args.key?(:reference_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
  @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value)
end