Class: Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::BatchGetDocumentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
The streamed response for Firestore.BatchGetDocuments.
Instance Attribute Summary collapse
-
#found ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document.
-
#missing ⇒ String
A document name that was requested but does not exist.
-
#read_time ⇒ String
The time at which the document was read.
-
#transaction ⇒ String
The transaction that was started as part of this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchGetDocumentsResponse
constructor
A new instance of BatchGetDocumentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchGetDocumentsResponse
Returns a new instance of BatchGetDocumentsResponse.
239 240 241 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 239 def initialize(**args) update!(**args) end |
Instance Attribute Details
#found ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document. Must not exceed 1 MiB - 4 bytes.
Corresponds to the JSON property found
216 217 218 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 216 def found @found end |
#missing ⇒ String
A document name that was requested but does not exist. In the format:
projects/project_id/databases/database_id/documents/document_path`.
Corresponds to the JSON propertymissing`
222 223 224 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 222 def missing @missing end |
#read_time ⇒ String
The time at which the document was read. This may be monotically increasing,
in this case the previous documents in the result stream are guaranteed not to
have changed between their read_time and this one.
Corresponds to the JSON property readTime
229 230 231 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 229 def read_time @read_time end |
#transaction ⇒ String
The transaction that was started as part of this request. Will only be set in
the first response, and only if BatchGetDocumentsRequest.new_transaction was
set in the request.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
237 238 239 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 237 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
244 245 246 247 248 249 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 244 def update!(**args) @found = args[:found] if args.key?(:found) @missing = args[:missing] if args.key?(:missing) @read_time = args[:read_time] if args.key?(:read_time) @transaction = args[:transaction] if args.key?(:transaction) end |