Class: Google::Apis::FirestoreV1beta1::ExecutePipelineRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::ExecutePipelineRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
The request for Firestore.ExecutePipeline.
Instance Attribute Summary collapse
-
#auto_commit_transaction ⇒ Boolean
(also: #auto_commit_transaction?)
Optional.
-
#new_transaction ⇒ Google::Apis::FirestoreV1beta1::TransactionOptions
Options for creating a new transaction.
-
#read_time ⇒ String
Execute the pipeline in a snapshot transaction at the given time.
-
#request_options ⇒ Google::Apis::FirestoreV1beta1::RequestOptions
Options for a server request.
-
#structured_pipeline ⇒ Google::Apis::FirestoreV1beta1::StructuredPipeline
A Firestore query represented as an ordered list of operations / stages.
-
#transaction ⇒ String
Run the query within an already active transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutePipelineRequest
constructor
A new instance of ExecutePipelineRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutePipelineRequest
Returns a new instance of ExecutePipelineRequest.
898 899 900 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 898 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_commit_transaction ⇒ Boolean Also known as: auto_commit_transaction?
Optional. Automatically commits the transaction after the pipeline has been
executed. Only permitted in combination with transaction or new_transaction
.
Corresponds to the JSON property autoCommitTransaction
862 863 864 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 862 def auto_commit_transaction @auto_commit_transaction end |
#new_transaction ⇒ Google::Apis::FirestoreV1beta1::TransactionOptions
Options for creating a new transaction.
Corresponds to the JSON property newTransaction
868 869 870 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 868 def new_transaction @new_transaction end |
#read_time ⇒ String
Execute the pipeline in a snapshot transaction at the given time. This must be
a microsecond precision timestamp within the past one hour, or if Point-in-
Time Recovery is enabled, can additionally be a whole minute timestamp within
the past 7 days.
Corresponds to the JSON property readTime
876 877 878 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 876 def read_time @read_time end |
#request_options ⇒ Google::Apis::FirestoreV1beta1::RequestOptions
Options for a server request.
Corresponds to the JSON property requestOptions
881 882 883 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 881 def @request_options end |
#structured_pipeline ⇒ Google::Apis::FirestoreV1beta1::StructuredPipeline
A Firestore query represented as an ordered list of operations / stages. This
is considered the top-level function which plans and executes a query. It is
logically equivalent to query(stages, options), but prevents the client from
having to build a function wrapper.
Corresponds to the JSON property structuredPipeline
889 890 891 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 889 def structured_pipeline @structured_pipeline end |
#transaction ⇒ String
Run the query within an already active transaction. The value here is the
opaque transaction ID to execute the query in.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
896 897 898 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 896 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
903 904 905 906 907 908 909 910 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 903 def update!(**args) @auto_commit_transaction = args[:auto_commit_transaction] if args.key?(:auto_commit_transaction) @new_transaction = args[:new_transaction] if args.key?(:new_transaction) @read_time = args[:read_time] if args.key?(:read_time) @request_options = args[:request_options] if args.key?(:request_options) @structured_pipeline = args[:structured_pipeline] if args.key?(:structured_pipeline) @transaction = args[:transaction] if args.key?(:transaction) end |