Class: Google::Apis::FirestoreV1beta1::ExecutePipelineRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.ExecutePipeline.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutePipelineRequest

Returns a new instance of ExecutePipelineRequest.



861
862
863
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_transactionGoogle::Apis::FirestoreV1beta1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



836
837
838
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 836

def new_transaction
  @new_transaction
end

#read_timeString

Execute the pipeline in a snapshot transaction at the given time. This must be a microsecond precision timestamp within the past one hour, or if Point-in- Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 844

def read_time
  @read_time
end

#structured_pipelineGoogle::Apis::FirestoreV1beta1::StructuredPipeline

A Firestore query represented as an ordered list of operations / stages. This is considered the top-level function which plans and executes a query. It is logically equivalent to query(stages, options), but prevents the client from having to build a function wrapper. Corresponds to the JSON property structuredPipeline



852
853
854
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 852

def structured_pipeline
  @structured_pipeline
end

#transactionString

Run the query within an already active transaction. The value here is the opaque transaction ID to execute the query in. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


859
860
861
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 859

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



866
867
868
869
870
871
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 866

def update!(**args)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @structured_pipeline = args[:structured_pipeline] if args.key?(:structured_pipeline)
  @transaction = args[:transaction] if args.key?(:transaction)
end