Class: Google::Apis::FirestoreV1beta1::ExecutePipelineResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::ExecutePipelineResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
The response for Firestore.Execute.
Instance Attribute Summary collapse
-
#execution_time ⇒ String
The time at which the results are valid.
-
#explain_stats ⇒ Google::Apis::FirestoreV1beta1::ExplainStats
Pipeline explain stats.
-
#results ⇒ Array<Google::Apis::FirestoreV1beta1::Document>
An ordered batch of results returned executing a pipeline.
-
#transaction ⇒ String
Newly created transaction identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecutePipelineResponse
constructor
A new instance of ExecutePipelineResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecutePipelineResponse
Returns a new instance of ExecutePipelineResponse.
914 915 916 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 914 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_time ⇒ String
The time at which the results are valid. This is a (not strictly)
monotonically increasing value across multiple responses in the same stream.
The API guarantees that all previously returned results are still valid at the
latest execution_time. This allows the API consumer to treat the query if it
ran at the latest execution_time returned. If the query returns no results,
a response with execution_time and no results will be sent, and this
represents the time at which the operation was run.
Corresponds to the JSON property executionTime
887 888 889 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 887 def execution_time @execution_time end |
#explain_stats ⇒ Google::Apis::FirestoreV1beta1::ExplainStats
Pipeline explain stats. Depending on the explain options in the original
request, this can contain the optimized plan and / or execution stats.
Corresponds to the JSON property explainStats
893 894 895 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 893 def explain_stats @explain_stats end |
#results ⇒ Array<Google::Apis::FirestoreV1beta1::Document>
An ordered batch of results returned executing a pipeline. The batch size is
variable, and can even be zero for when only a partial progress message is
returned. The fields present in the returned documents are only those that
were explicitly requested in the pipeline, this includes those like __name__
and __update_time__. This is explicitly a divergence from Firestore.
RunQuery / Firestore.GetDocument RPCs which always return such fields even
when they are not specified in the mask.
Corresponds to the JSON property results
904 905 906 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 904 def results @results end |
#transaction ⇒ String
Newly created transaction identifier. This field is only specified as part of
the first response from the server, alongside the results field when the
original request specified ExecuteRequest.new_transaction.
Corresponds to the JSON property transaction
NOTE: Values are automatically base64 encoded/decoded in the client library.
912 913 914 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 912 def transaction @transaction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
919 920 921 922 923 924 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 919 def update!(**args) @execution_time = args[:execution_time] if args.key?(:execution_time) @explain_stats = args[:explain_stats] if args.key?(:explain_stats) @results = args[:results] if args.key?(:results) @transaction = args[:transaction] if args.key?(:transaction) end |