Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. BulkDeleteDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.



1402
1403
1404
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

The IDs of the collection groups that are being deleted. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


1360
1361
1362
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1360

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


1366
1367
1368
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1366

def end_time
  @end_time
end

#namespace_idsArray<String>

Which namespace IDs are being deleted. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


1371
1372
1373
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1371

def namespace_ids
  @namespace_ids
end

#operation_stateString

The state of the operation. Corresponds to the JSON property operationState

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1376

def operation_state
  @operation_state
end

#progress_bytesGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



1382
1383
1384
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1382

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



1388
1389
1390
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1388

def progress_documents
  @progress_documents
end

#snapshot_timeString

The timestamp that corresponds to the version of the database that is being read to get the list of documents to delete. This time can also be used as the timestamp of PITR in case of disaster recovery (subject to PITR window limit). Corresponds to the JSON property snapshotTime

Returns:

  • (String)


1395
1396
1397
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1395

def snapshot_time
  @snapshot_time
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


1400
1401
1402
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1400

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1407

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end