Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for google.longrunning.Operation results from FirestoreAdmin. BulkDeleteDocuments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata

Returns a new instance of GoogleFirestoreAdminV1BulkDeleteDocumentsMetadata.



1363
1364
1365
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collection_idsArray<String>

The IDs of the collection groups that are being deleted. Corresponds to the JSON property collectionIds

Returns:

  • (Array<String>)


1321
1322
1323
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1321

def collection_ids
  @collection_ids
end

#end_timeString

The time this operation completed. Will be unset if operation still in progress. Corresponds to the JSON property endTime

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1327

def end_time
  @end_time
end

#namespace_idsArray<String>

Which namespace IDs are being deleted. Corresponds to the JSON property namespaceIds

Returns:

  • (Array<String>)


1332
1333
1334
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1332

def namespace_ids
  @namespace_ids
end

#operation_stateString

The state of the operation. Corresponds to the JSON property operationState

Returns:

  • (String)


1337
1338
1339
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1337

def operation_state
  @operation_state
end

#progress_bytesGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressBytes



1343
1344
1345
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1343

def progress_bytes
  @progress_bytes
end

#progress_documentsGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressDocuments



1349
1350
1351
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1349

def progress_documents
  @progress_documents
end

#snapshot_timeString

The timestamp that corresponds to the version of the database that is being read to get the list of documents to delete. This time can also be used as the timestamp of PITR in case of disaster recovery (subject to PITR window limit). Corresponds to the JSON property snapshotTime

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1356

def snapshot_time
  @snapshot_time
end

#start_timeString

The time this operation started. Corresponds to the JSON property startTime

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1361

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1368

def update!(**args)
  @collection_ids = args[:collection_ids] if args.key?(:collection_ids)
  @end_time = args[:end_time] if args.key?(:end_time)
  @namespace_ids = args[:namespace_ids] if args.key?(:namespace_ids)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_bytes = args[:progress_bytes] if args.key?(:progress_bytes)
  @progress_documents = args[:progress_documents] if args.key?(:progress_documents)
  @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end