Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1CloneDatabaseMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
Metadata for the long-running operation from the CloneDatabase request.
Instance Attribute Summary collapse
-
#database ⇒ String
The name of the database being cloned to.
-
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
-
#operation_state ⇒ String
The operation state of the clone.
-
#pitr_snapshot ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time.
-
#progress_percentage ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation.
-
#start_time ⇒ String
The time the clone was started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
constructor
A new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1CloneDatabaseMetadata
Returns a new instance of GoogleFirestoreAdminV1CloneDatabaseMetadata.
1419 1420 1421 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
The name of the database being cloned to.
Corresponds to the JSON property database
1387 1388 1389 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1387 def database @database end |
#end_time ⇒ String
The time the clone finished, unset for ongoing clones.
Corresponds to the JSON property endTime
1392 1393 1394 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1392 def end_time @end_time end |
#operation_state ⇒ String
The operation state of the clone.
Corresponds to the JSON property operationState
1397 1398 1399 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1397 def operation_state @operation_state end |
#pitr_snapshot ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot
A consistent snapshot of a database at a specific point in time. A PITR (Point-
in-time recovery) snapshot with previous versions of a database's data is
available for every minute up to the associated database's data retention
period. If the PITR feature is enabled, the retention period is 7 days;
otherwise, it is one hour.
Corresponds to the JSON property pitrSnapshot
1406 1407 1408 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1406 def pitr_snapshot @pitr_snapshot end |
#progress_percentage ⇒ Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress
Describes the progress of the operation. Unit of work is generic and must be
interpreted based on where Progress is used.
Corresponds to the JSON property progressPercentage
1412 1413 1414 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1412 def progress_percentage @progress_percentage end |
#start_time ⇒ String
The time the clone was started.
Corresponds to the JSON property startTime
1417 1418 1419 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1417 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1424 1425 1426 1427 1428 1429 1430 1431 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1424 def update!(**args) @database = args[:database] if args.key?(:database) @end_time = args[:end_time] if args.key?(:end_time) @operation_state = args[:operation_state] if args.key?(:operation_state) @pitr_snapshot = args[:pitr_snapshot] if args.key?(:pitr_snapshot) @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage) @start_time = args[:start_time] if args.key?(:start_time) end |