Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1PitrSnapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A consistent snapshot of a database at a specific point in time. A PITR (Point- in-time recovery) snapshot with previous versions of a database's data is available for every minute up to the associated database's data retention period. If the PITR feature is enabled, the retention period is 7 days; otherwise, it is one hour.
Instance Attribute Summary collapse
-
#database ⇒ String
Required.
-
#database_uid ⇒ String
Output only.
-
#snapshot_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1PitrSnapshot
constructor
A new instance of GoogleFirestoreAdminV1PitrSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1PitrSnapshot
Returns a new instance of GoogleFirestoreAdminV1PitrSnapshot.
1485 1486 1487 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database ⇒ String
Required. The name of the database that this was a snapshot of. Format:
projects/project/databases/database`.
Corresponds to the JSON propertydatabase`
1472 1473 1474 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1472 def database @database end |
#database_uid ⇒ String
Output only. Public UUID of the database the snapshot was associated with.
Corresponds to the JSON property databaseUid
NOTE: Values are automatically base64 encoded/decoded in the client library.
1478 1479 1480 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1478 def database_uid @database_uid end |
#snapshot_time ⇒ String
Required. Snapshot time of the database.
Corresponds to the JSON property snapshotTime
1483 1484 1485 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1483 def snapshot_time @snapshot_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1490 1491 1492 1493 1494 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1490 def update!(**args) @database = args[:database] if args.key?(:database) @database_uid = args[:database_uid] if args.key?(:database_uid) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) end |