Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1RestoreDatabaseMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

Metadata for the long-running operation from the RestoreDatabase request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirestoreAdminV1RestoreDatabaseMetadata

Returns a new instance of GoogleFirestoreAdminV1RestoreDatabaseMetadata.



1597
1598
1599
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backupString

The name of the backup restoring from. Corresponds to the JSON property backup

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1569

def backup
  @backup
end

#databaseString

The name of the database being restored to. Corresponds to the JSON property database

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1574

def database
  @database
end

#end_timeString

The time the restore finished, unset for ongoing restores. Corresponds to the JSON property endTime

Returns:

  • (String)


1579
1580
1581
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1579

def end_time
  @end_time
end

#operation_stateString

The operation state of the restore. Corresponds to the JSON property operationState

Returns:

  • (String)


1584
1585
1586
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1584

def operation_state
  @operation_state
end

#progress_percentageGoogle::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1Progress

Describes the progress of the operation. Unit of work is generic and must be interpreted based on where Progress is used. Corresponds to the JSON property progressPercentage



1590
1591
1592
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1590

def progress_percentage
  @progress_percentage
end

#start_timeString

The time the restore was started. Corresponds to the JSON property startTime

Returns:

  • (String)


1595
1596
1597
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1595

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1602
1603
1604
1605
1606
1607
1608
1609
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1602

def update!(**args)
  @backup = args[:backup] if args.key?(:backup)
  @database = args[:database] if args.key?(:database)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_state = args[:operation_state] if args.key?(:operation_state)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @start_time = args[:start_time] if args.key?(:start_time)
end