Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
Measures the progress of a particular metric.
Instance Attribute Summary collapse
-
#work_completed ⇒ Fixnum
An estimate of how much work has been completed.
-
#work_estimated ⇒ Fixnum
An estimate of how much work needs to be performed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1Progress
constructor
A new instance of GoogleFirestoreAdminV1beta1Progress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1Progress
Returns a new instance of GoogleFirestoreAdminV1beta1Progress.
1991 1992 1993 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#work_completed ⇒ Fixnum
An estimate of how much work has been completed. Note that this may be greater
than work_estimated.
Corresponds to the JSON property workCompleted
1983 1984 1985 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1983 def work_completed @work_completed end |
#work_estimated ⇒ Fixnum
An estimate of how much work needs to be performed. Zero if the work estimate
is unavailable. May change as work progresses.
Corresponds to the JSON property workEstimated
1989 1990 1991 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1989 def work_estimated @work_estimated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1996 1997 1998 1999 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1996 def update!(**args) @work_completed = args[:work_completed] if args.key?(:work_completed) @work_estimated = args[:work_estimated] if args.key?(:work_estimated) end |