Class: Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::GoogleFirestoreAdminV1beta1Progress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
Measures the progress of a particular metric.
Instance Attribute Summary collapse
-
#work_completed ⇒ Fixnum
An estimate of how much work has been completed.
-
#work_estimated ⇒ Fixnum
An estimate of how much work needs to be performed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1Progress
constructor
A new instance of GoogleFirestoreAdminV1beta1Progress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirestoreAdminV1beta1Progress
Returns a new instance of GoogleFirestoreAdminV1beta1Progress.
1952 1953 1954 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#work_completed ⇒ Fixnum
An estimate of how much work has been completed. Note that this may be greater
than work_estimated.
Corresponds to the JSON property workCompleted
1944 1945 1946 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1944 def work_completed @work_completed end |
#work_estimated ⇒ Fixnum
An estimate of how much work needs to be performed. Zero if the work estimate
is unavailable. May change as work progresses.
Corresponds to the JSON property workEstimated
1950 1951 1952 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1950 def work_estimated @work_estimated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1957 1958 1959 1960 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 1957 def update!(**args) @work_completed = args[:work_completed] if args.key?(:work_completed) @work_estimated = args[:work_estimated] if args.key?(:work_estimated) end |