Class: Google::Apis::FirestoreV1beta1::RunQueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

The request for Firestore.RunQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunQueryRequest

Returns a new instance of RunQueryRequest.



2677
2678
2679
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explain_optionsGoogle::Apis::FirestoreV1beta1::ExplainOptions

Explain options for the query. Corresponds to the JSON property explainOptions



2649
2650
2651
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2649

def explain_options
  @explain_options
end

#new_transactionGoogle::Apis::FirestoreV1beta1::TransactionOptions

Options for creating a new transaction. Corresponds to the JSON property newTransaction



2654
2655
2656
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2654

def new_transaction
  @new_transaction
end

#read_timeString

Reads documents as they were at the given time. This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days. Corresponds to the JSON property readTime

Returns:

  • (String)


2661
2662
2663
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2661

def read_time
  @read_time
end

#structured_queryGoogle::Apis::FirestoreV1beta1::StructuredQuery

A Firestore query. The query stages are executed in the following order: 1. from 2. where 3. select 4. order_by + start_at + end_at 5. offset 6. limit 7. find_nearest Corresponds to the JSON property structuredQuery



2668
2669
2670
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2668

def structured_query
  @structured_query
end

#transactionString

Run the query within an already active transaction. The value here is the opaque transaction ID to execute the query in. Corresponds to the JSON property transaction NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


2675
2676
2677
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2675

def transaction
  @transaction
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2682
2683
2684
2685
2686
2687
2688
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2682

def update!(**args)
  @explain_options = args[:explain_options] if args.key?(:explain_options)
  @new_transaction = args[:new_transaction] if args.key?(:new_transaction)
  @read_time = args[:read_time] if args.key?(:read_time)
  @structured_query = args[:structured_query] if args.key?(:structured_query)
  @transaction = args[:transaction] if args.key?(:transaction)
end