Class: Google::Apis::FirestoreV1beta1::StructuredPipeline
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::StructuredPipeline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A Firestore query represented as an ordered list of operations / stages. This
is considered the top-level function which plans and executes a query. It is
logically equivalent to query(stages, options), but prevents the client from
having to build a function wrapper.
Instance Attribute Summary collapse
-
#options ⇒ Hash<String,Google::Apis::FirestoreV1beta1::Value>
Optional.
-
#pipeline ⇒ Google::Apis::FirestoreV1beta1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructuredPipeline
constructor
A new instance of StructuredPipeline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructuredPipeline
Returns a new instance of StructuredPipeline.
2872 2873 2874 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2872 def initialize(**args) update!(**args) end |
Instance Attribute Details
#options ⇒ Hash<String,Google::Apis::FirestoreV1beta1::Value>
Optional. Optional query-level arguments.
Corresponds to the JSON property options
2865 2866 2867 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2865 def @options end |
#pipeline ⇒ Google::Apis::FirestoreV1beta1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Corresponds to the JSON property pipeline
2870 2871 2872 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2870 def pipeline @pipeline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2877 2878 2879 2880 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 2877 def update!(**args) @options = args[:options] if args.key?(:options) @pipeline = args[:pipeline] if args.key?(:pipeline) end |