Class: Google::Apis::FirestoreV1beta1::Target
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::Target
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A specification of a set of documents to listen to.
Instance Attribute Summary collapse
-
#documents ⇒ Google::Apis::FirestoreV1beta1::DocumentsTarget
A target specified by a set of documents names.
-
#expected_count ⇒ Fixnum
The number of documents that last matched the query at the resume token or read time.
-
#once ⇒ Boolean
(also: #once?)
If the target should be removed once it is current and consistent.
-
#query ⇒ Google::Apis::FirestoreV1beta1::QueryTarget
A target specified by a query.
-
#read_time ⇒ String
Start listening after a specific
read_time. -
#resume_token ⇒ String
A resume token from a prior TargetChange for an identical target.
-
#target_id ⇒ Fixnum
The target ID that identifies the target on the stream.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Target
constructor
A new instance of Target.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Target
Returns a new instance of Target.
3167 3168 3169 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3167 def initialize(**args) update!(**args) end |
Instance Attribute Details
#documents ⇒ Google::Apis::FirestoreV1beta1::DocumentsTarget
A target specified by a set of documents names.
Corresponds to the JSON property documents
3117 3118 3119 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3117 def documents @documents end |
#expected_count ⇒ Fixnum
The number of documents that last matched the query at the resume token or
read time. This value is only relevant when a resume_type is provided. This
value being present and greater than zero signals that the client wants
ExistenceFilter.unchanged_names to be included in the response.
Corresponds to the JSON property expectedCount
3125 3126 3127 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3125 def expected_count @expected_count end |
#once ⇒ Boolean Also known as: once?
If the target should be removed once it is current and consistent.
Corresponds to the JSON property once
3130 3131 3132 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3130 def once @once end |
#query ⇒ Google::Apis::FirestoreV1beta1::QueryTarget
A target specified by a query.
Corresponds to the JSON property query
3136 3137 3138 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3136 def query @query end |
#read_time ⇒ String
Start listening after a specific read_time. The client must know the state
of matching documents at this time.
Corresponds to the JSON property readTime
3142 3143 3144 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3142 def read_time @read_time end |
#resume_token ⇒ String
A resume token from a prior TargetChange for an identical target. Using a
resume token with a different target is unsupported and may fail.
Corresponds to the JSON property resumeToken
NOTE: Values are automatically base64 encoded/decoded in the client library.
3149 3150 3151 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3149 def resume_token @resume_token end |
#target_id ⇒ Fixnum
The target ID that identifies the target on the stream. Must be a positive
number and non-zero. If target_id is 0 (or unspecified), the server will
assign an ID for this target and return that in a TargetChange::ADD event.
Once a target with target_id=0 is added, all subsequent targets must also
have target_id=0. If an AddTarget request with target_id != 0 is sent to
the server after a target with target_id=0 is added, the server will
immediately send a response with a TargetChange::Remove event. Note that if
the client sends multiple AddTarget requests without an ID, the order of IDs
returned in TargetChange.target_ids are undefined. Therefore, clients should
provide a target ID instead of relying on the server to assign one. If
target_id is non-zero, there must not be an existing active target on this
stream with the same ID.
Corresponds to the JSON property targetId
3165 3166 3167 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3165 def target_id @target_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3172 3173 3174 3175 3176 3177 3178 3179 3180 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3172 def update!(**args) @documents = args[:documents] if args.key?(:documents) @expected_count = args[:expected_count] if args.key?(:expected_count) @once = args[:once] if args.key?(:once) @query = args[:query] if args.key?(:query) @read_time = args[:read_time] if args.key?(:read_time) @resume_token = args[:resume_token] if args.key?(:resume_token) @target_id = args[:target_id] if args.key?(:target_id) end |