Class: Google::Apis::FirestoreV1beta1::Target

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A specification of a set of documents to listen to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Target

Returns a new instance of Target.



3059
3060
3061
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#documentsGoogle::Apis::FirestoreV1beta1::DocumentsTarget

A target specified by a set of documents names. Corresponds to the JSON property documents



3009
3010
3011
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3009

def documents
  @documents
end

#expected_countFixnum

The number of documents that last matched the query at the resume token or read time. This value is only relevant when a resume_type is provided. This value being present and greater than zero signals that the client wants ExistenceFilter.unchanged_names to be included in the response. Corresponds to the JSON property expectedCount

Returns:

  • (Fixnum)


3017
3018
3019
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3017

def expected_count
  @expected_count
end

#onceBoolean Also known as: once?

If the target should be removed once it is current and consistent. Corresponds to the JSON property once

Returns:

  • (Boolean)


3022
3023
3024
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3022

def once
  @once
end

#queryGoogle::Apis::FirestoreV1beta1::QueryTarget

A target specified by a query. Corresponds to the JSON property query



3028
3029
3030
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3028

def query
  @query
end

#read_timeString

Start listening after a specific read_time. The client must know the state of matching documents at this time. Corresponds to the JSON property readTime

Returns:

  • (String)


3034
3035
3036
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3034

def read_time
  @read_time
end

#resume_tokenString

A resume token from a prior TargetChange for an identical target. Using a resume token with a different target is unsupported and may fail. Corresponds to the JSON property resumeToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3041
3042
3043
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3041

def resume_token
  @resume_token
end

#target_idFixnum

The target ID that identifies the target on the stream. Must be a positive number and non-zero. If target_id is 0 (or unspecified), the server will assign an ID for this target and return that in a TargetChange::ADD event. Once a target with target_id=0 is added, all subsequent targets must also have target_id=0. If an AddTarget request with target_id != 0 is sent to the server after a target with target_id=0 is added, the server will immediately send a response with a TargetChange::Remove event. Note that if the client sends multiple AddTarget requests without an ID, the order of IDs returned in TargetChange.target_ids are undefined. Therefore, clients should provide a target ID instead of relying on the server to assign one. If target_id is non-zero, there must not be an existing active target on this stream with the same ID. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


3057
3058
3059
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3057

def target_id
  @target_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3064
3065
3066
3067
3068
3069
3070
3071
3072
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3064

def update!(**args)
  @documents = args[:documents] if args.key?(:documents)
  @expected_count = args[:expected_count] if args.key?(:expected_count)
  @once = args[:once] if args.key?(:once)
  @query = args[:query] if args.key?(:query)
  @read_time = args[:read_time] if args.key?(:read_time)
  @resume_token = args[:resume_token] if args.key?(:resume_token)
  @target_id = args[:target_id] if args.key?(:target_id)
end