Class: Google::Apis::FirestoreV1beta1::Value

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A message that can hold any of the supported value types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Value

Returns a new instance of Value.



3292
3293
3294
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valueGoogle::Apis::FirestoreV1beta1::ArrayValue

An array value. Corresponds to the JSON property arrayValue



3203
3204
3205
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3203

def array_value
  @array_value
end

#boolean_valueBoolean Also known as: boolean_value?

A boolean value. Corresponds to the JSON property booleanValue

Returns:

  • (Boolean)


3208
3209
3210
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3208

def boolean_value
  @boolean_value
end

#bytes_valueString

A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes are considered by queries. Corresponds to the JSON property bytesValue NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3216
3217
3218
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3216

def bytes_value
  @bytes_value
end

#double_valueFloat

A double value. Corresponds to the JSON property doubleValue

Returns:

  • (Float)


3221
3222
3223
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3221

def double_value
  @double_value
end

#field_reference_valueString

Value which references a field. This is considered relative (vs absolute) since it only refers to a field and not a field within a particular document. * Requires:* * Must follow field reference limitations. * Not allowed to be used when writing documents. Corresponds to the JSON property fieldReferenceValue

Returns:

  • (String)


3229
3230
3231
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3229

def field_reference_value
  @field_reference_value
end

#function_valueGoogle::Apis::FirestoreV1beta1::Function

Represents an unevaluated scalar expression. For example, the expression like( user_name, "%alice%") is represented as: name: "like" args ` field_reference: "user_name" ` args ` string_value: "%alice%" ` Corresponds to the JSON property functionValue



3236
3237
3238
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3236

def function_value
  @function_value
end

#geo_point_valueGoogle::Apis::FirestoreV1beta1::LatLng

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges. Corresponds to the JSON property geoPointValue



3244
3245
3246
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3244

def geo_point_value
  @geo_point_value
end

#integer_valueFixnum

An integer value. Corresponds to the JSON property integerValue

Returns:

  • (Fixnum)


3249
3250
3251
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3249

def integer_value
  @integer_value
end

#map_valueGoogle::Apis::FirestoreV1beta1::MapValue

A map value. Corresponds to the JSON property mapValue



3254
3255
3256
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3254

def map_value
  @map_value
end

#null_valueString

A null value. Corresponds to the JSON property nullValue

Returns:

  • (String)


3259
3260
3261
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3259

def null_value
  @null_value
end

#pipeline_valueGoogle::Apis::FirestoreV1beta1::Pipeline

A Firestore query represented as an ordered list of operations / stages. Corresponds to the JSON property pipelineValue



3264
3265
3266
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3264

def pipeline_value
  @pipeline_value
end

#reference_valueString

A reference to a document. For example: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertyreferenceValue`

Returns:

  • (String)


3270
3271
3272
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3270

def reference_value
  @reference_value
end

#string_valueString

A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes of the UTF-8 representation are considered by queries. Corresponds to the JSON property stringValue

Returns:

  • (String)


3277
3278
3279
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3277

def string_value
  @string_value
end

#timestamp_valueString

A timestamp value. Precise only to microseconds. When stored, any additional precision is rounded down. Corresponds to the JSON property timestampValue

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3283

def timestamp_value
  @timestamp_value
end

#variable_reference_valueString

Pointer to a variable defined elsewhere in a pipeline. Unlike field_reference_value which references a field within a document, this refers to a variable, defined in a separate namespace than the fields of a document. Corresponds to the JSON property variableReferenceValue

Returns:

  • (String)


3290
3291
3292
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3290

def variable_reference_value
  @variable_reference_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3297
3298
3299
3300
3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
3311
3312
3313
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3297

def update!(**args)
  @array_value = args[:array_value] if args.key?(:array_value)
  @boolean_value = args[:boolean_value] if args.key?(:boolean_value)
  @bytes_value = args[:bytes_value] if args.key?(:bytes_value)
  @double_value = args[:double_value] if args.key?(:double_value)
  @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value)
  @function_value = args[:function_value] if args.key?(:function_value)
  @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value)
  @integer_value = args[:integer_value] if args.key?(:integer_value)
  @map_value = args[:map_value] if args.key?(:map_value)
  @null_value = args[:null_value] if args.key?(:null_value)
  @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value)
  @reference_value = args[:reference_value] if args.key?(:reference_value)
  @string_value = args[:string_value] if args.key?(:string_value)
  @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value)
  @variable_reference_value = args[:variable_reference_value] if args.key?(:variable_reference_value)
end