Class: Google::Apis::FirestoreV1beta1::Value
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A message that can hold any of the supported value types.
Instance Attribute Summary collapse
-
#array_value ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
A boolean value.
-
#bytes_value ⇒ String
A bytes value.
-
#double_value ⇒ Float
A double value.
-
#field_reference_value ⇒ String
Value which references a field.
-
#function_value ⇒ Google::Apis::FirestoreV1beta1::Function
Represents an unevaluated scalar expression.
-
#geo_point_value ⇒ Google::Apis::FirestoreV1beta1::LatLng
An object that represents a latitude/longitude pair.
-
#integer_value ⇒ Fixnum
An integer value.
-
#map_value ⇒ Google::Apis::FirestoreV1beta1::MapValue
A map value.
-
#null_value ⇒ String
A null value.
-
#pipeline_value ⇒ Google::Apis::FirestoreV1beta1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
-
#reference_value ⇒ String
A reference to a document.
-
#string_value ⇒ String
A string value.
-
#timestamp_value ⇒ String
A timestamp value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
3273 3274 3275 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#array_value ⇒ Google::Apis::FirestoreV1beta1::ArrayValue
An array value.
Corresponds to the JSON property arrayValue
3191 3192 3193 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3191 def array_value @array_value end |
#boolean_value ⇒ Boolean Also known as: boolean_value?
A boolean value.
Corresponds to the JSON property booleanValue
3196 3197 3198 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3196 def boolean_value @boolean_value end |
#bytes_value ⇒ String
A bytes value. Must not exceed 1 MiB - 89 bytes. Only the first 1,500 bytes
are considered by queries.
Corresponds to the JSON property bytesValue
NOTE: Values are automatically base64 encoded/decoded in the client library.
3204 3205 3206 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3204 def bytes_value @bytes_value end |
#double_value ⇒ Float
A double value.
Corresponds to the JSON property doubleValue
3209 3210 3211 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3209 def double_value @double_value end |
#field_reference_value ⇒ String
Value which references a field. This is considered relative (vs absolute)
since it only refers to a field and not a field within a particular document. *
Requires:* * Must follow field reference limitations. * Not allowed to be
used when writing documents.
Corresponds to the JSON property fieldReferenceValue
3217 3218 3219 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3217 def field_reference_value @field_reference_value end |
#function_value ⇒ Google::Apis::FirestoreV1beta1::Function
Represents an unevaluated scalar expression. For example, the expression like(
user_name, "%alice%") is represented as: name: "like" args `
field_reference: "user_name" ` args ` string_value: "%alice%" `
Corresponds to the JSON property functionValue
3224 3225 3226 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3224 def function_value @function_value end |
#geo_point_value ⇒ Google::Apis::FirestoreV1beta1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property geoPointValue
3232 3233 3234 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3232 def geo_point_value @geo_point_value end |
#integer_value ⇒ Fixnum
An integer value.
Corresponds to the JSON property integerValue
3237 3238 3239 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3237 def integer_value @integer_value end |
#map_value ⇒ Google::Apis::FirestoreV1beta1::MapValue
A map value.
Corresponds to the JSON property mapValue
3242 3243 3244 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3242 def map_value @map_value end |
#null_value ⇒ String
A null value.
Corresponds to the JSON property nullValue
3247 3248 3249 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3247 def null_value @null_value end |
#pipeline_value ⇒ Google::Apis::FirestoreV1beta1::Pipeline
A Firestore query represented as an ordered list of operations / stages.
Corresponds to the JSON property pipelineValue
3252 3253 3254 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3252 def pipeline_value @pipeline_value end |
#reference_value ⇒ String
A reference to a document. For example: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertyreferenceValue`
3258 3259 3260 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3258 def reference_value @reference_value end |
#string_value ⇒ String
A string value. The string, represented as UTF-8, must not exceed 1 MiB - 89
bytes. Only the first 1,500 bytes of the UTF-8 representation are considered
by queries.
Corresponds to the JSON property stringValue
3265 3266 3267 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3265 def string_value @string_value end |
#timestamp_value ⇒ String
A timestamp value. Precise only to microseconds. When stored, any additional
precision is rounded down.
Corresponds to the JSON property timestampValue
3271 3272 3273 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3271 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3278 def update!(**args) @array_value = args[:array_value] if args.key?(:array_value) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @bytes_value = args[:bytes_value] if args.key?(:bytes_value) @double_value = args[:double_value] if args.key?(:double_value) @field_reference_value = args[:field_reference_value] if args.key?(:field_reference_value) @function_value = args[:function_value] if args.key?(:function_value) @geo_point_value = args[:geo_point_value] if args.key?(:geo_point_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @map_value = args[:map_value] if args.key?(:map_value) @null_value = args[:null_value] if args.key?(:null_value) @pipeline_value = args[:pipeline_value] if args.key?(:pipeline_value) @reference_value = args[:reference_value] if args.key?(:reference_value) @string_value = args[:string_value] if args.key?(:string_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |