Class: Google::Apis::FirestoreV1beta1::Write
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::Write
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A write on a document.
Instance Attribute Summary collapse
-
#current_document ⇒ Google::Apis::FirestoreV1beta1::Precondition
A precondition on a document, used for conditional operations.
-
#delete ⇒ String
A document name to delete.
-
#transform ⇒ Google::Apis::FirestoreV1beta1::DocumentTransform
A transformation of a document.
-
#update ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document.
-
#update_mask ⇒ Google::Apis::FirestoreV1beta1::DocumentMask
A set of field paths on a document.
-
#update_transforms ⇒ Array<Google::Apis::FirestoreV1beta1::FieldTransform>
The transforms to perform after update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Write
constructor
A new instance of Write.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Write
Returns a new instance of Write.
3473 3474 3475 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_document ⇒ Google::Apis::FirestoreV1beta1::Precondition
A precondition on a document, used for conditional operations.
Corresponds to the JSON property currentDocument
3440 3441 3442 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3440 def current_document @current_document end |
#delete ⇒ String
A document name to delete. In the format: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertydelete`
3446 3447 3448 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3446 def delete @delete end |
#transform ⇒ Google::Apis::FirestoreV1beta1::DocumentTransform
A transformation of a document.
Corresponds to the JSON property transform
3451 3452 3453 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3451 def transform @transform end |
#update ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document. Must not exceed 1 MiB - 4 bytes.
Corresponds to the JSON property update
3456 3457 3458 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3456 def update @update end |
#update_mask ⇒ Google::Apis::FirestoreV1beta1::DocumentMask
A set of field paths on a document. Used to restrict a get or update operation
on a document to a subset of its fields. This is different from standard field
masks, as this is always scoped to a Document, and takes in account the
dynamic nature of Value.
Corresponds to the JSON property updateMask
3464 3465 3466 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3464 def update_mask @update_mask end |
#update_transforms ⇒ Array<Google::Apis::FirestoreV1beta1::FieldTransform>
The transforms to perform after update. This field can be set only when the
operation is update. If present, this write is equivalent to performing
update and transform to the same document atomically and in order.
Corresponds to the JSON property updateTransforms
3471 3472 3473 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3471 def update_transforms @update_transforms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3478 3479 3480 3481 3482 3483 3484 3485 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3478 def update!(**args) @current_document = args[:current_document] if args.key?(:current_document) @delete = args[:delete] if args.key?(:delete) @transform = args[:transform] if args.key?(:transform) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) @update_transforms = args[:update_transforms] if args.key?(:update_transforms) end |