Class: Google::Apis::FirestoreV1beta1::Write

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb

Overview

A write on a document.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Write

Returns a new instance of Write.



3365
3366
3367
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_documentGoogle::Apis::FirestoreV1beta1::Precondition

A precondition on a document, used for conditional operations. Corresponds to the JSON property currentDocument



3332
3333
3334
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3332

def current_document
  @current_document
end

#deleteString

A document name to delete. In the format: projects/project_id/databases/ database_id/documents/document_path`. Corresponds to the JSON propertydelete`

Returns:

  • (String)


3338
3339
3340
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3338

def delete
  @delete
end

#transformGoogle::Apis::FirestoreV1beta1::DocumentTransform

A transformation of a document. Corresponds to the JSON property transform



3343
3344
3345
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3343

def transform
  @transform
end

#updateGoogle::Apis::FirestoreV1beta1::Document

A Firestore document. Must not exceed 1 MiB - 4 bytes. Corresponds to the JSON property update



3348
3349
3350
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3348

def update
  @update
end

#update_maskGoogle::Apis::FirestoreV1beta1::DocumentMask

A set of field paths on a document. Used to restrict a get or update operation on a document to a subset of its fields. This is different from standard field masks, as this is always scoped to a Document, and takes in account the dynamic nature of Value. Corresponds to the JSON property updateMask



3356
3357
3358
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3356

def update_mask
  @update_mask
end

#update_transformsArray<Google::Apis::FirestoreV1beta1::FieldTransform>

The transforms to perform after update. This field can be set only when the operation is update. If present, this write is equivalent to performing update and transform to the same document atomically and in order. Corresponds to the JSON property updateTransforms



3363
3364
3365
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3363

def update_transforms
  @update_transforms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3370
3371
3372
3373
3374
3375
3376
3377
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3370

def update!(**args)
  @current_document = args[:current_document] if args.key?(:current_document)
  @delete = args[:delete] if args.key?(:delete)
  @transform = args[:transform] if args.key?(:transform)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
  @update_transforms = args[:update_transforms] if args.key?(:update_transforms)
end