Class: Google::Apis::FirestoreV1beta1::Write
- Inherits:
-
Object
- Object
- Google::Apis::FirestoreV1beta1::Write
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firestore_v1beta1/classes.rb,
lib/google/apis/firestore_v1beta1/representations.rb,
lib/google/apis/firestore_v1beta1/representations.rb
Overview
A write on a document.
Instance Attribute Summary collapse
-
#current_document ⇒ Google::Apis::FirestoreV1beta1::Precondition
A precondition on a document, used for conditional operations.
-
#delete ⇒ String
A document name to delete.
-
#transform ⇒ Google::Apis::FirestoreV1beta1::DocumentTransform
A transformation of a document.
-
#update ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document.
-
#update_mask ⇒ Google::Apis::FirestoreV1beta1::DocumentMask
A set of field paths on a document.
-
#update_transforms ⇒ Array<Google::Apis::FirestoreV1beta1::FieldTransform>
The transforms to perform after update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Write
constructor
A new instance of Write.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Write
Returns a new instance of Write.
3336 3337 3338 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_document ⇒ Google::Apis::FirestoreV1beta1::Precondition
A precondition on a document, used for conditional operations.
Corresponds to the JSON property currentDocument
3303 3304 3305 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3303 def current_document @current_document end |
#delete ⇒ String
A document name to delete. In the format: projects/project_id/databases/
database_id/documents/document_path`.
Corresponds to the JSON propertydelete`
3309 3310 3311 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3309 def delete @delete end |
#transform ⇒ Google::Apis::FirestoreV1beta1::DocumentTransform
A transformation of a document.
Corresponds to the JSON property transform
3314 3315 3316 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3314 def transform @transform end |
#update ⇒ Google::Apis::FirestoreV1beta1::Document
A Firestore document. Must not exceed 1 MiB - 4 bytes.
Corresponds to the JSON property update
3319 3320 3321 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3319 def update @update end |
#update_mask ⇒ Google::Apis::FirestoreV1beta1::DocumentMask
A set of field paths on a document. Used to restrict a get or update operation
on a document to a subset of its fields. This is different from standard field
masks, as this is always scoped to a Document, and takes in account the
dynamic nature of Value.
Corresponds to the JSON property updateMask
3327 3328 3329 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3327 def update_mask @update_mask end |
#update_transforms ⇒ Array<Google::Apis::FirestoreV1beta1::FieldTransform>
The transforms to perform after update. This field can be set only when the
operation is update. If present, this write is equivalent to performing
update and transform to the same document atomically and in order.
Corresponds to the JSON property updateTransforms
3334 3335 3336 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3334 def update_transforms @update_transforms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/google/apis/firestore_v1beta1/classes.rb', line 3341 def update!(**args) @current_document = args[:current_document] if args.key?(:current_document) @delete = args[:delete] if args.key?(:delete) @transform = args[:transform] if args.key?(:transform) @update = args[:update] if args.key?(:update) @update_mask = args[:update_mask] if args.key?(:update_mask) @update_transforms = args[:update_transforms] if args.key?(:update_transforms) end |